@@ -1,6 +1,7 @@
 import requests
 import json
-from .endpoints import e621_endpoints as e621end
+#import e621_endpoints as e621end
+from . import e621_endpoints as e621end
 headers = {
     'User-Agent': 'E621 api wrapper',
 }
@@ -18,6 +19,8 @@ class client:
         self.tags = e621end.tags(self)
         self.notes = e621end.notes(self)
         self.util = e621end.util(self)
+        self.wiki = e621end.wiki(self)
+        self.forum = e621end.forum(self)
     
     def login(self, username, apikey):
         #try user login
